********************************************
:mod:`gruvi.util` -- Miscellaneous utilities
********************************************

The :mod:`gruvi.util` module contains some miscellaneous utility functions.

.. automodule:: gruvi.util
   :members:
